==> handsontable-0.32.0.jar: META-INF/resources/webjars/handsontable/0.32.0/es/plugins/index.js <==
import AutoColumnSize from './autoColumnSize/autoColumnSize';
import AutoFill from './autofill/autofill';
import AutoRowSize from './autoRowSize/autoRowSize';
import ColumnSorting from './columnSorting/columnSorting';
import Comments from './comments/comments';
import ContextMenu from './contextMenu/contextMenu';
import ContextMenuCopyPaste from './contextMenuCopyPaste/contextMenuCopyPaste';
import CopyPaste from './copyPaste/copyPaste';
import CustomBorders from './customBorders/customBorders';
import DragToScroll from './dragToScroll/dragToScroll';
import ManualColumnFreeze from './manualColumnFreeze/manualColumnFreeze';
import ManualColumnMove from './manualColumnMove/manualColumnMove';
import ManualColumnResize from './manualColumnResize/manualColumnResize';
import ManualRowMove from './manualRowMove/manualRowMove';
import ManualRowResize from './manualRowResize/manualRowResize';
import MergeCells from './mergeCells/mergeCells';
import MultipleSelectionHandles from './multipleSelectionHandles/multipleSelectionHandles';
import ObserveChanges from './observeChanges/observeChanges';
import PersistentState from './persistentState/persistentState';
import Search from './search/search';
import TouchScroll from './touchScroll/touchScroll';
import UndoRedo from './undoRedo/undoRedo';
import Base from './_base';

export { AutoColumnSize, AutoFill, AutoRowSize, ColumnSorting, Comments, ContextMenu, ContextMenuCopyPaste, CopyPaste, CustomBorders, DragToScroll, ManualColumnFreeze, ManualColumnMove, ManualColumnResize, ManualRowMove, ManualRowResize, MergeCells, MultipleSelectionHandles, ObserveChanges, PersistentState, Search, TouchScroll, UndoRedo, Base };

==> handsontable-2.0.0.jar: META-INF/resources/webjars/handsontable/2.0.0/es/plugins/index.js <==
import PersistentState from './persistentState/persistentState';
import AutoColumnSize from './autoColumnSize/autoColumnSize';
import AutoFill from './autofill/autofill';
import AutoRowSize from './autoRowSize/autoRowSize';
import ColumnSorting from './columnSorting/columnSorting';
import Comments from './comments/comments';
import ContextMenu from './contextMenu/contextMenu';
import CopyPaste from './copyPaste/copyPaste';
import CustomBorders from './customBorders/customBorders';
import DragToScroll from './dragToScroll/dragToScroll';
import ManualColumnFreeze from './manualColumnFreeze/manualColumnFreeze';
import ManualColumnMove from './manualColumnMove/manualColumnMove';
import ManualColumnResize from './manualColumnResize/manualColumnResize';
import ManualRowMove from './manualRowMove/manualRowMove';
import ManualRowResize from './manualRowResize/manualRowResize';
import MergeCells from './mergeCells/mergeCells';
import MultipleSelectionHandles from './multipleSelectionHandles/multipleSelectionHandles';
import ObserveChanges from './observeChanges/observeChanges';
import Search from './search/search';
import TouchScroll from './touchScroll/touchScroll';
import UndoRedo from './undoRedo/undoRedo';
import Base from './_base';

export { AutoColumnSize, AutoFill, AutoRowSize, ColumnSorting, Comments, ContextMenu, CopyPaste, CustomBorders, DragToScroll, ManualColumnFreeze, ManualColumnMove, ManualColumnResize, ManualRowMove, ManualRowResize, MergeCells, MultipleSelectionHandles, ObserveChanges, PersistentState, Search, TouchScroll, UndoRedo, Base };
